@@ -21,7 +21,7 @@ import os
 import tempfile
 import numbers
 import logging
-from distutils.version import StrictVersion
+from distutils.version import LooseVersion
 
 import numpy as np
 import scipy
@@ -975,8 +975,8 @@ class BaseModel(list):
             if fitter == "leastsq":
                 if bounded:
                     # leastsq with bounds requires scipy >= 0.17
-                    if StrictVersion(
-                            scipy.__version__) < StrictVersion("0.17"):
+                    if LooseVersion(
+                            scipy.__version__) < LooseVersion("0.17"):
                         raise ImportError(
                             "leastsq with bounds requires SciPy >= 0.17")
 
@@ -1722,12 +1722,13 @@ class ModelSpecialSlicers(object):
             slices,
             self.isNavigation)
         _signal = self.model.signal._slicer(slices, self.isNavigation)
-        if _signal.metadata.Signal.signal_type == 'EELS':
-            _model = _signal.create_model(
-                auto_background=False,
-                auto_add_edges=False)
-        else:
-            _model = _signal.create_model()
+        # TODO: for next major release, change model creation defaults to not
+        # automate anything. For now we explicitly look for "auto_" kwargs and
+        # disable them:
+        import inspect
+        pars = inspect.signature(_signal.create_model).parameters
+        kwargs = {key: False for key in pars.keys() if key.startswith('auto_')}
+        _model = _signal.create_model(**kwargs)
 
         dims = (self.model.axes_manager.navigation_dimension,
                 self.model.axes_manager.signal_dimension)
