@@ -156,10 +156,10 @@ class TestSamfireEmpty:
     def test_setup(self):
         m = self.model
         samf = m.create_samfire(workers=1, setup=False)
-        nt.assert_is_none(samf.metadata.gt_dump)
+        nt.assert_is_none(samf.metadata._gt_dump)
         nt.assert_is_none(samf.pool)
         samf._setup(ipyparallel=False)
-        nt.assert_is_not_none(samf.metadata.gt_dump)
+        nt.assert_is_not_none(samf.metadata._gt_dump)
         nt.assert_is_not_none(samf.pool)
 
     def test_samfire_init_marker(self):
@@ -438,7 +438,7 @@ class TestSamfireWorker:
         self.args = {}
         self.model_letter = 'sldkfjg'
         from hyperspy.samfire_utils.fit_tests import red_chisq_test as rct
-        self.gt_dump = dill.dumps(rct(tolerance=1.0))
+        self._gt_dump = dill.dumps(rct(tolerance=1.0))
         m_slice = m.inav[self.ind[::-1]]
         m_slice.store(self.model_letter)
         m_dict = m_slice.signal._to_dictionary(False)
@@ -458,7 +458,7 @@ class TestSamfireWorker:
     def test_main_result(self):
         worker = create_worker('worker')
         worker.create_model(self.model_dictionary, self.model_letter)
-        worker.setup_test(self.gt_dump)
+        worker.setup_test(self._gt_dump)
         worker.set_optional_names({self.model[comp].name for comp in
                                    self.optional_comps})
         self.vals.update({
